@@ -8,12 +8,12 @@ def corr_matrix(df):
 
     # definir el heatmap
     plt.figure( figsize=(10, 8))
-    h_map = sns.heatmap(X.corr().values, 
+    h_map = sns.heatmap(df.corr().values, 
                         vmin=-1., vmax=1., 
                         cmap=cMap, 
                         annot=True, 
-                        xticklabels=list(X.columns[ : -1]),
-                        yticklabels=list(X.columns[ : -1]))
+                        xticklabels=list(df.columns[ : -1]),
+                        yticklabels=list(df.columns[ : -1]))
     plt.xticks(rotation=90) 
     
     # poner ticks en la barra de colores
